nfldb is a relational database bundled with a Python module to quickly and 
conveniently query and
[update that database](https://github.com/BurntSushi/nfldb/wiki/Updating-nfldb-with-real-time-data).

Stay tuned. More is coming in this space.


## Entity-relationship diagram

Here's a condensed version that excludes play and player statistics:

[![Shortened ER diagram for nfldb](http://burntsushi.net/stuff/nfldb/nfldb-condensed.png)](http://burntsushi.net/stuff/nfldb/nfldb-condensed.pdf)

There is also a [full PDF version](http://burntsushi.net/stuff/nfldb/nfldb.pdf)
that includes every column in the database.

